@@ -141,9 +141,9 @@ def setup(settings_path=None, **settings_patches):
     print section_title('Deploy target is: %s' % beanstalk_stack_base)
     local('mkdir -p %s' % beanstalk_stack_base)
     local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'global-logs'))
-    local('echo "{}" >> %s' % os.path.join(beanstalk_stack_base, 'apps'))
+    local('echo "{}" >> %s' % apps_pool_path())
     local('chmod o+rx %s' % beanstalk_stack_base)
-    local('chown beanstalk:beanstalk %s' % beanstalk_stack_base)
+    local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
 
 
 @task
@@ -203,7 +203,7 @@ def create_app(project_name, settings_path=None, **settings_patches):
         }
 
         return apps_pool
-    edit_file(apps_pool_path(), editor)
+    edit_file(apps_pool_path(), editor=editor)
 
 
 @task
