@@ -1,7 +1,7 @@
 import os
 from fabric.api import *
 from fabric.state import output as output_level
-from soil.datastucture import SettingsDict
+from ground_soil.datastucture import SettingsDict
 from beanstalk import (BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH,
                        BEANSTALK_LOCAL_BASE_PATH)
 from beanstalk.titles import section_title
